@@ -2,7 +2,7 @@
 * manager.cpp: Vls manager
 *-------------------------------------------------------------------------------
 * (c)1999-2001 VideoLAN
-* $Id: manager.cpp,v 1.20 2002/09/30 15:17:53 jpsaman Exp $
+* $Id: manager.cpp,v 1.22 2002/12/09 01:36:24 nitrox Exp $
 *
 * Authors: Benoit Steiner <benny@via.ecp.fr>
 *          Arnaud de Bossoreille de Ribou <bozo@via.ecp.fr>
@@ -401,8 +401,13 @@ void C_Manager::StopPrograms()
     HandleRequest(cRequest);
     LogDbg(m_hLog, "Remove the broadcast");
     m_cBroadcasts.Lock();
+#ifdef DEBUG 
     int iRc = m_cBroadcasts.Remove(cRequest.GetArg("program") + ":" +
                                    cRequest.GetArg("input"));
+#else
+    m_cBroadcasts.Remove(cRequest.GetArg("program") + ":" +
+                                   cRequest.GetArg("input"));
+#endif
     m_cBroadcasts.UnLock();
     LogDbg(m_hLog, C_String("Broadcast removed with status ") + iRc);
   }
@@ -801,7 +806,7 @@ C_Answer C_Manager::Start(const C_Request& cRequest)
   if(!pPgrm)
   {
     cAnswer.SetStatus(GEN_ERR);
-    cAnswer.AddMessage("Unknown pgrm");
+    cAnswer.AddMessage("Unknown pgrm "+strPgrm);
   }  
    
   // Find the input
@@ -950,7 +955,11 @@ C_Answer C_Manager::Stop(const C_Request& cRequest)
     m_cInputList.Release(pInput->GetName());
 
     LogDbg(m_hLog, "Remove the broadcast");
+#ifdef DEBUG
     int iRc = m_cBroadcasts.Remove(strChannel);
+#else
+    m_cBroadcasts.Remove(strChannel);
+#endif
     LogDbg(m_hLog, C_String("Broadcast removed with status ") + iRc);
   }
   else
@@ -1418,62 +1427,6 @@ C_Answer C_Manager::Input(const C_Request& cRequest)
       cAnswer.SetStatus(GEN_ERR);
       cAnswer.AddMessage( "Input type \"dvb\" expects \"device number\"." );
     }
-    strDeviceType = cRequest.GetArg("device_type");
-    ASSERT( strDeviceType != "" );
-    if (strDeviceType == "")
-    {
-      cAnswer.SetStatus(GEN_ERR);
-      cAnswer.AddMessage( "Input type \"dvb\" expects \"device type\" (nova)." );
-    }
-    strFrequency = cRequest.GetArg("frequency");
-    ASSERT( strFrequency != "" );
-    if (strFrequency == "")
-    {
-      cAnswer.SetStatus(GEN_ERR);
-      cAnswer.AddMessage( "Input type \"dvb\" expects \"transponder frequency\"." );
-    }
-    strPolarization = cRequest.GetArg("polarization");
-    ASSERT( strPolarization != "" );
-    if (strPolarization == "")
-    {
-      cAnswer.SetStatus(GEN_ERR);
-      cAnswer.AddMessage( "Input type \"dvb\" expects \"polarization\" (0 is vertical and 1 is horizontal)." );
-    }
-    strSymbolRate = cRequest.GetArg("symbol_rate");
-    ASSERT( strSymbolRate != "" );
-    if (strSymbolRate == "")
-    {
-      cAnswer.SetStatus(GEN_ERR);
-      cAnswer.AddMessage( "Input type \"dvb\" expects \"symbol rate\"." );
-    }
-    strUseDiSEqC = cRequest.GetArg("use_disecq");
-    ASSERT( strUseDiSEqC != "" );
-    if (strUseDiSEqC == "")
-    {
-      cAnswer.SetStatus(GEN_ERR);
-      cAnswer.AddMessage( "Input type \"dvb\" expects \"use DiSEqC\" (0 is false and 1 is true)." );
-    }
-    strLNB_Lof1 = cRequest.GetArg("lnb_lof1");
-    ASSERT( strLNB_Lof1 != "" );
-    if (strLNB_Lof1  == "")
-    {
-      cAnswer.SetStatus(GEN_ERR);
-      cAnswer.AddMessage( "Input type \"dvb\" expects \"LNB_Lof1\"." );
-    }
-    strLNB_Lof2 = cRequest.GetArg("lnb_lof2");
-    ASSERT( strLNB_Lof2 != "" );
-    if (strLNB_Lof2  == "")
-    {
-      cAnswer.SetStatus(GEN_ERR);
-      cAnswer.AddMessage( "Input type \"dvb\" expects \"LNB_Lof2\"." );
-    }
-    strLNB_SLof = cRequest.GetArg("lnb_slof");
-    ASSERT( strLNB_SLof != "" );
-    if (strLNB_SLof  == "")
-    {
-      cAnswer.SetStatus(GEN_ERR);
-      cAnswer.AddMessage( "Input type \"dvb\" expects \"SLNB_Lof\"." );
-    }
   }
   // Check for errors in command syntax
   if (cAnswer.GetStatus() == GEN_ERR)
@@ -1537,22 +1490,6 @@ C_Answer C_Manager::Input(const C_Request& cRequest)
     {
       strKey = strInputName+C_String(".DeviceNumber");
       pApp->SetSettings( strKey, strDeviceNumber );
-      strKey = strInputName+C_String(".DeviceType");
-      pApp->SetSettings( strKey, strDeviceType );
-      strKey = strInputName+C_String(".Frequency");
-      pApp->SetSettings( strKey, strFrequency );
-      strKey = strInputName+C_String(".Polarization");
-      pApp->SetSettings( strKey, strPolarization );
-      strKey = strInputName+C_String(".SymbolRate");
-      pApp->SetSettings( strKey, strSymbolRate );
-      strKey = strInputName+C_String(".DiSEqc");
-      pApp->SetSettings( strKey, strUseDiSEqC );
-      strKey = strInputName+C_String(".LNB_Lof1");
-      pApp->SetSettings( strKey, strLNB_Lof1 );
-      strKey = strInputName+C_String(".LNB_Lof2");
-      pApp->SetSettings( strKey, strLNB_Lof2 );
-      strKey = strInputName+C_String(".LNB_SLof");
-      pApp->SetSettings( strKey, strLNB_SLof );
     }
 
     // Create the input for the given source
@@ -1656,30 +1593,6 @@ C_Answer C_Manager::Input(const C_Request& cRequest)
         strKey = strInputName+C_String(".DeviceNumber");
         if (pApp->GetSetting(strKey, "") != "")
           pApp->DeleteSetting(strKey);
-        strKey = strInputName+C_String(".DeviceType");
-        if (pApp->GetSetting(strKey, "") != "")
-          pApp->DeleteSetting(strKey);
-        strKey = strInputName+C_String(".Frequency");
-        if (pApp->GetSetting(strKey, "") != "")
-          pApp->DeleteSetting(strKey);
-        strKey = strInputName+C_String(".Polarization");
-        if (pApp->GetSetting(strKey, "") != "")
-          pApp->DeleteSetting(strKey);
-        strKey = strInputName+C_String(".SymbolRate");
-        if (pApp->GetSetting(strKey, "") != "")
-          pApp->DeleteSetting(strKey);
-        strKey = strInputName+C_String(".DiSEqc");
-        if (pApp->GetSetting(strKey, "") != "")
-          pApp->DeleteSetting(strKey);
-        strKey = strInputName+C_String(".LNB_Lof1");
-        if (pApp->GetSetting(strKey, "") != "")
-          pApp->DeleteSetting(strKey);
-        strKey = strInputName+C_String(".LNB_Lof2");
-        if (pApp->GetSetting(strKey, "") != "")
-          pApp->DeleteSetting(strKey);
-        strKey = strInputName+C_String(".LNB_SLof");
-        if (pApp->GetSetting(strKey, "") != "")
-          pApp->DeleteSetting(strKey);
       }
       Log(m_hLog, LOG_NOTE, "Input '" + strInputName + "' removed !");
     }
