@@ -2,7 +2,7 @@
 * telnet.cpp:
 *-------------------------------------------------------------------------------
 * (c)1999-2001 VideoLAN
-* $Id: telnet.cpp,v 1.7 2002/08/14 11:13:27 tooney Exp $
+* $Id: telnet.cpp,v 1.8.4.1 2003/03/06 04:19:20 tooney Exp $
 *
 * Authors: Benoit Steiner <benny@via.ecp.fr>
 *          Arnaud de Bossoreille de Ribou <bozo@via.ecp.fr>
@@ -709,51 +709,58 @@ int C_Telnet::Init()
 
   int iRc = NO_ERR;
 
-  // Get config
-  C_String strDomain = pApp->GetSetting("Telnet.Domain", "Inet4").ToLower();
-
-  int iDomain;
-  C_String strDefaultHost;
-
-  if(strDomain == "inet4")
-  {
-    iDomain = AF_INET;
-    strDefaultHost = "0.0.0.0";
-  }
-#ifdef HAVE_IPV6
-  else if(strDomain == "inet6")
-  {
-    iDomain = AF_INET6;
-    strDefaultHost = "0::0";
-  }
+  //Don't start the telnet server when Telnet.Use is false
+#ifdef WIN32
+  if(pApp->GetSetting("Telnet.Use", "true").ToLower()=="true")
+#else
+  if(pApp->GetSetting("Telnet.Use", "false").ToLower()=="true")
 #endif
-  else
   {
-    Log(m_hLog, LOG_ERROR, "Unknown domain:\n" + strDomain);
-    iRc = GEN_ERR;
-  }
-
-  if(!iRc)
-  {
-    C_String strAddr = pApp->GetSetting("Telnet.LocalAddress", strDefaultHost);
-    C_String strPort = pApp->GetSetting("Telnet.LocalPort", "9999");
-
-    // Init the socket
-    try
+    // Get config
+    C_String strDomain = pApp->GetSetting("Telnet.Domain", "Inet4").ToLower();
+ 
+    int iDomain;
+    C_String strDefaultHost;
+ 
+    if(strDomain == "inet4")
     {
-      C_ConnectionsHandler<C_TelnetSession>::Init(iDomain, strAddr, strPort);
+      iDomain = AF_INET;
+      strDefaultHost = "0.0.0.0";
     }
-    catch(E_Exception e)
+#ifdef HAVE_IPV6
+    else if(strDomain == "inet6")
     {
-      Log(m_hLog, LOG_ERROR,
-          "Telnet server initialisation failed:\n" + e.Dump());
+      iDomain = AF_INET6;
+      strDefaultHost = "0::0";
+    }
+#endif
+    else
+    {
+      Log(m_hLog, LOG_ERROR, "Unknown domain:\n" + strDomain);
       iRc = GEN_ERR;
     }
-  }
-  
-  if(!iRc)
-    Log(m_hLog, LOG_NOTE, "Telnet server initialised");
 
+    if(!iRc)
+    {
+      C_String strAddr = pApp->GetSetting("Telnet.LocalAddress", strDefaultHost);
+      C_String strPort = pApp->GetSetting("Telnet.LocalPort", "9999");
+
+      // Init the socket
+      try
+      {
+        C_ConnectionsHandler<C_TelnetSession>::Init(iDomain, strAddr, strPort);
+      }
+      catch(E_Exception e)
+      {
+        Log(m_hLog, LOG_ERROR,
+            "Telnet server initialisation failed:\n" + e.Dump());
+        iRc = GEN_ERR;
+      }
+    }
+  
+    if(!iRc)
+      Log(m_hLog, LOG_NOTE, "Telnet server initialised");
+  }
   return iRc;
 }
 
